/***************************************************************************
 *   Copyright (C) 2007 by David Rivoal                                    *
 *   davidrivoal@free.fr                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef MAILBOX_H
#define MAILBOX_H

#include <qobject.h>
#include <qsocket.h>
#include <qstring.h>
#include <qtextstream.h>
#include <qdns.h>
#include <qtimer.h>

/**
	@author David Rivoal <davidrivoal@free.fr>
*/

const int sockTimeout = 30000;

class Mailbox : public QObject
{
	Q_OBJECT

	public :
		Mailbox(QString f_boxserver, QString f_user, QString f_password, bool f_boxIsPop);
		~Mailbox();
		void changeBox(QString f_boxserver, QString f_user, QString f_password, bool f_boxIsPop);
		void requestServer();

	signals :
		void serverResponse(int errorCode, int nbMess = -1);
		/*
			errorCode :
				0 = OK
				1 = DNS Lookup error
				2 = Server refused connection
				3 = User authentication failed
				4 = Reading Statistics failed
				5 = Connection timeout
		*/

	protected :
		bool isOk(QString resp);
		void popRead();
		void imapRead();

		QSocket *boxSocket;
		QString boxserver, user, password;
		bool boxIsPop;
		QTextStream *socketBuf;
		QDns *serverLookup;
		QTimer *timerTimeout;
		
		enum State {S_INIT, S_AUTH, S_USER, S_PASS, S_STAT, S_QUIT};
		int state;

	protected slots :
		void socketRead();
		void socketTimeout();
		void connectServer();
};

#endif
